@@ -23,7 +23,10 @@ from datalad_next.itertools import (
     decode_bytes,
     itemize,
 )
-from datalad_next.runners import call_git_oneline
+from datalad_next.runners import (
+    call_git,
+    call_git_oneline,
+)
 
 from .gittree import (
     GitTreeItem,
@@ -84,10 +87,14 @@ class GitDiffItem(GitTreeItem):
     """This is the percentage of similarity for copy-status and
     rename-status diff items, and the percentage of dissimilarity
     for modifications."""
-    modification_types: tuple[GitContainerModificationType] | None = None
+    modification_types: tuple[GitContainerModificationType, ...] | None = None
     """Qualifiers for modification types of container-type
     items (directories, submodules)."""
 
+    def __post_init__(self):
+        if self.status == GitDiffStatus.addition and self.gitsha is None:
+            self.add_modification_type(GitContainerModificationType.modified_content)
+
     @cached_property
     def prev_path(self) -> PurePosixPath | None:
         """Returns the item ``prev_name`` as a ``PurePosixPath``
@@ -210,6 +217,19 @@ def iter_gitdiff(
 
     cmd = _build_cmd(**kwargs)
 
+    if cmd[0] == 'diff-index':
+        # when we compare to the index, we need a refresh run to not have
+        # something like plain mtime changes trigger modification reports
+        # https://github.com/datalad/datalad-next/issues/639
+        call_git([
+            'update-index',
+            # must come first, we recurse ourselves
+            '--ignore-submodules',
+            # we want to continue the refresh when the index need updating
+            '-q',
+            '--refresh',
+        ], cwd=path)
+
     # when do we need to condense subdir reports into a single dir-report
     reported_dirs: set[str] = set()
     _single_dir = (cmd[0] == 'diff-index') and recursive == 'no'
