@@ -11,6 +11,7 @@ from pathlib import (
 )
 from typing import Generator
 
+from datalad_next.consts import PRE_INIT_COMMIT_SHA
 from datalad_next.runners import (
     CommandError,
     call_git_lines,
@@ -22,7 +23,6 @@ from datalad_next.itertools import (
 )
 from datalad_next.repo_utils import (
     get_worktree_head,
-    iter_submodules,
 )
 
 from .gitdiff import (
@@ -35,6 +35,7 @@ from .gitworktree import (
     GitTreeItem,
     GitTreeItemType,
     iter_gitworktree,
+    iter_submodules,
     lsfiles_untracked_args,
     _git_ls_files,
 )
@@ -95,10 +96,19 @@ def iter_gitstatus(
       The ``name`` and ``prev_name`` attributes of an item are a ``str`` with
       the corresponding (relative) path, as reported by Git
       (in POSIX conventions).
+
+    .. note::
+
+       The implementation requires `git rev-parse --path-format=relative`
+       that was introduced with Git v2.31.
     """
     path = Path(path)
 
     head, corresponding_head = get_worktree_head(path)
+    if head is None:
+        # no commit at all -> compare to an empty repo.
+        head = PRE_INIT_COMMIT_SHA
+
     # TODO it would make sense to always (or optionally) compare against any
     # existing corresponding_head. This would make the status communicate
     # anything that has not made it into the corresponding branch yet
@@ -162,15 +172,15 @@ def _yield_dir_items(
             )
         }
     # diff constrained to direct children
-    for item in ([] if head is None else iter_gitdiff(
+    for item in iter_gitdiff(
         path,
-        from_treeish='HEAD',
+        from_treeish=head,
         # to the worktree
         to_treeish=None,
         recursive='no',
         # TODO trim scope like in repo_items
         eval_submodule_state=eval_submodule_state,
-    )):
+    ):
         if item.status != GitDiffStatus.deletion \
                 and item.gittype in container_types:
             if item.gittype == GitTreeItemType.submodule:
@@ -251,9 +261,9 @@ def _yield_repo_items(
         str(item.name): item for item in iter_submodules(path)
     }
     # start with a repository-contrained diff against the worktree
-    for item in ([] if head is None else iter_gitdiff(
+    for item in iter_gitdiff(
         path,
-        from_treeish='HEAD',
+        from_treeish=head,
         # to the worktree
         to_treeish=None,
         recursive='repository',
@@ -261,7 +271,7 @@ def _yield_repo_items(
         # We need to redo some check for adjusted mode, and other cases anyways
         eval_submodule_state='commit'
         if eval_submodule_state == 'full' else eval_submodule_state,
-    )):
+    ):
         # immediately investigate any submodules that are already
         # reported modified by Git
         if item.gittype == GitTreeItemType.submodule:
@@ -316,12 +326,14 @@ def _yield_hierarchy_items(
         # TODO do we need to adjust the eval mode here for the diff recmodes?
         eval_submodule_state=eval_submodule_state,
     ):
-        # we get to see any submodule item passing through here, and can simply
-        # call this function again for a subpath
+        # there is nothing else to do for any non-submodule item
         if item.gittype != GitTreeItemType.submodule:
             yield item
             continue
 
+        # we get to see any submodule item passing through here, and can simply
+        # call this function again for a subpath
+
         # submodule recursion
         # the .path of a GitTreeItem is always POSIX
         sm_path = path / item.path
@@ -342,6 +354,14 @@ def _yield_hierarchy_items(
             # repository, hence no submodule item is emitted
             sm_head = item.gitsha or item.prev_gitsha
 
+            if GitContainerModificationType.new_commits in item.modification_types:
+                # this is a submodule that has new commits compared to
+                # its state in the parent dataset. We need to yield this
+                # item, even if nothing else is modified, because otherwise
+                # this (unsafed) changed would go unnoticed
+                # https://github.com/datalad/datalad-next/issues/645
+                yield item
+
         for i in _yield_hierarchy_items(
             head=sm_head,
             path=sm_path,
