@@ -14,4 +14,8 @@ from . import (
     create_sibling_gitlab,
     run,
     update,
+    # the following two patches have been taken verbatim from datalad-ria
+    ssh_exec,
+    sshconnector,
+    patch_ria_ora,
 )
