@@ -1,4 +1,4 @@
-from datalad_next.tests.utils import (
+from datalad_next.tests import (
     DEFAULT_REMOTE,
     assert_result_count,
 )
